# Generated by roxygen2: do not edit by hand

S3method(plot,rlme)
S3method(summary,rlme)
export(GEER_est)
export(GR_est)
export(JR_est)
export(LM_est)
export(beta_var)
export(compare.fits)
export(dispvar)
export(fitdvcov)
export(getgrstplot)
export(getlmestplot)
export(hbrwts_gr)
export(lmr)
export(minimize_dispersion)
export(rhosch)
export(rhosect)
export(rlme)
export(rpr)
export(rprmeddis)
export(stanresidgr)
export(wilonestep)
export(wilstep)
import(Rcpp)
import(graphics)
import(stats)
importFrom(MASS,ginv)
importFrom(MASS,huber)
importFrom(MASS,lmsreg)
importFrom(MASS,ltsreg)
importFrom(magic,adiag)
importFrom(mgcv,extract.lme.cov2)
importFrom(nlme,lme)
importFrom(nlme,random.effects)
importFrom(quantreg,rq)
importFrom(quantreg,rq.fit.br)
importFrom(quantreg,rq.fit.fnb)
importFrom(robustbase,covMcd)
importFrom(stringr,str_extract_all)
importFrom(utils,tail)
useDynLib(rlme)
